@@ -19,6 +19,7 @@ class RoleTreeService(object):
         tree = []
         for item in data_list:
             if str(item['parent_role_id']) == str(parent_group):
+                item['name'] = item['role_name']
                 item['children'] = RoleTreeService.getTree(data_list, item['id'])
                 tree.append(item)
         return tree
@@ -31,6 +32,7 @@ class RoleTreeService(object):
             base_node = Role.objects.filter(id=parent_group).to_json()  # 如果是搜索，则获取该节点角色信息
             for item in data_list:
                 if str(item['parent_role_id']) == str(parent_group):
+                    item['name'] = item['role_name']
                     item['children'] = RoleTreeService.getTree(data_list, item['id'])
                     tree.append(item)
             base_node[0]['children'] = tree
@@ -40,6 +42,7 @@ class RoleTreeService(object):
                 if not str(item['parent_role_id']) == str(parent_group):
                     continue
                 child = RoleTreeService.getTree(data_list, item['id'])
+                item['name'] = item['role_name']
                 item['children'] = child
                 tree.append(item)
         return tree
@@ -69,6 +72,7 @@ class RoleService:
             for i in user_list:
                 id(i)
                 i["is_role"] = True
+                i["name"] = i["role_name"]
             return user_list, None
         # 分页查询
         page = params.pop("page", 1)
